#
# This script used for building msi package
#
# Required environment variables:
#
# WORKSPACE
# JDK_HOME
# WIXDIR
# WIXGEN_URL
# BUNDLE_URL
# PROPERTIES_URL

REPO=`cd \`dirname $0\`; pwd`

function fail() {
  echo $*
  exit 1
}

[ -d "${WORKSPACE}" ] || fail "Invalid $WORKSPACE"
[ -d "${JDK_HOME}" ] || fail "Invalid $JDK_HOME"
[ -d "${WIXDIR}" ] || fail "Invalid $WIXDIR"

[ -n "${WIXGEN_URL}" ] || fail "Invalid WIXGEN_URL"
[ -n "${BUNDLE_URL}" ] || fail "Indefined BUNDLE_URL"
[ -n "${PROPERTIES_URL}" ] || fail "Invalid PROPERTIES_URL"

WORKSPACE=`cygpath -u ${WORKSPACE}`

OUTCOME=${WORKSPACE}/outcome
mkdir -p ${OUTCOME}

BUILDDIR=$(mktemp -d ${WORKSPACE}/build.XXXXXX)
BUILDDIR=`cygpath -p -m ${BUILDDIR}`
cd ${BUILDDIR}

WIXGEN_FILE=${BUILDDIR}/$(basename "${WIXGEN_URL}")
BUNDLE_FILE=${BUILDDIR}/$(basename "${BUNDLE_URL}")
PROPERTIES_FILE=${BUILDDIR}/$(basename "${PROPERTIES_URL}")

[ -f "${WIXGEN_FILE}" ] || wget ${WIXGEN_URL}
[ -f "${BUNDLE_FILE}" ] || wget ${BUNDLE_URL}
[ -f "${PROPERTIES_FILE}" ] || wget ${PROPERTIES_URL}

REPO=`cygpath -p -m ${REPO}`
sed -i -e "s|ZULU_ICEDTEA_SRC|${REPO}|g" ${PROPERTIES_FILE}
IMAGEDIR=${BUILDDIR}/icedtea-web-image
[ -d "${IMAGEDIR}" ] || unzip -q ${BUNDLE_FILE}

"${JDK_HOME}/bin/java" -jar ${WIXGEN_FILE} ${IMAGEDIR} -c ${PROPERTIES_FILE} -o "${BUILDDIR}/itw-installer.wxs"
"${WIXDIR}"/candle.exe /nologo itw-installer.wxs
"${WIXDIR}"/light.exe /nologo -sval -ext WixUIExtension itw-installer.wixobj

MSI_FILE=$(basename ${BUNDLE_FILE/.bin.zip/.msi})
mv itw-installer.msi ${OUTCOME}/${MSI_FILE}

echo "BUILD_DESCRIPTION: ${MSI_FILE}"
